Crate wiwi_chain

Crate wiwi_chain 

Structs

ArrayChain
ArrayMutChain
OutputDebug
StringChain
StringMutChain
VecChain
VecMutChain

Traits

Chain
ChainConversions
Trait implemented on chains and their inner types, allowing you to get a reference to the inner type regardless of if the chain or the inner type is passed in
ChainInner
Output
Safety
WithSelf

Functions

out_dbg
Tool for helping to debug Output trait usage in debug mode (if out is not written to, the function will panic)