Crate wiwi_chain
wiwi_
chain
0.11.0-pre.3
All Items
Crate Items
Structs
Traits
Functions
Crate
wiwi_
chain
Structs

Array
Chain
Array
MutChain
Output
Debug
String
Chain
String
MutChain
VecChain
VecMut
Chain
Traits

Chain
Chain
Conversions
Trait implemented on chains and their inner types, allowing you to get a reference to the inner type regardless of if the chain or the inner type is passed in
Chain
Inner
Output
Safety
With
Self
Functions

out_dbg
Tool for helping to debug
Output
trait usage in debug mode (if
out
is not written to, the function will panic)